summaryrefslogtreecommitdiff
path: root/include/llvm/PassAnalysisSupport.h
diff options
context:
space:
mode:
authorChris Lattner <sabre@nondot.org>2002-10-21 20:00:28 +0000
committerChris Lattner <sabre@nondot.org>2002-10-21 20:00:28 +0000
commitcb2610ea037a17115ef3a01a6bdaab4e3cfdca27 (patch)
tree868d175bc12cc58b644aea2bea47e87cbe4933c7 /include/llvm/PassAnalysisSupport.h
parent8291e0465b3864050c050a61db4fcd844cc0b52e (diff)
downloadllvm-cb2610ea037a17115ef3a01a6bdaab4e3cfdca27.tar.gz
llvm-cb2610ea037a17115ef3a01a6bdaab4e3cfdca27.tar.bz2
llvm-cb2610ea037a17115ef3a01a6bdaab4e3cfdca27.tar.xz
- Rename AnalysisUsage::preservesAll to getPreservesAll & preservesCFG to
setPreservesCFG to be less confusing. git-svn-id: https://llvm.org/svn/llvm-project/llvm/trunk@4255 91177308-0d34-0410-b5e6-96231b3b80d8
Diffstat (limited to 'include/llvm/PassAnalysisSupport.h')
-rw-r--r--include/llvm/PassAnalysisSupport.h23
1 files changed, 12 insertions, 11 deletions
diff --git a/include/llvm/PassAnalysisSupport.h b/include/llvm/PassAnalysisSupport.h
index 82fc9cb1b2..38987b5615 100644
--- a/include/llvm/PassAnalysisSupport.h
+++ b/include/llvm/PassAnalysisSupport.h
@@ -61,17 +61,18 @@ public:
// setPreservesAll - Set by analyses that do not transform their input at all
void setPreservesAll() { PreservesAll = true; }
- bool preservesAll() const { return PreservesAll; }
-
- // preservesCFG - This function should be called by the pass, iff they do not:
- //
- // 1. Add or remove basic blocks from the function
- // 2. Modify terminator instructions in any way.
- //
- // This function annotates the AnalysisUsage info object to say that analyses
- // that only depend on the CFG are preserved by this pass.
- //
- void preservesCFG();
+ bool getPreservesAll() const { return PreservesAll; }
+
+ /// setPreservesCFG - This function should be called by the pass, iff they do
+ /// not:
+ ///
+ /// 1. Add or remove basic blocks from the function
+ /// 2. Modify terminator instructions in any way.
+ ///
+ /// This function annotates the AnalysisUsage info object to say that analyses
+ /// that only depend on the CFG are preserved by this pass.
+ ///
+ void setPreservesCFG();
const std::vector<AnalysisID> &getRequiredSet() const { return Required; }
const std::vector<AnalysisID> &getPreservedSet() const { return Preserved; }